package
Version:
v0.0.0-...-85855aa
Opens a new window with list of versions in this module.
Published: Apr 25, 2026
License: MIT
Opens a new window with license information.
Imports: 8
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type BackupMetadata struct {
Timestamp time.Time `json:"timestamp"`
Hostname string `json:"hostname"`
OS string `json:"os"`
PolkitVersion string `json:"polkit_version"`
FilesCount int `json:"files_count"`
TotalSize int64 `json:"total_size"`
}
type Config struct {
Paths []string `json:"paths"`
Compress bool `json:"compress"`
IncludeMeta bool `json:"include_meta"`
OutputPath string `json:"output_path"`
BackupDir string `json:"backup_dir"`
RetentionDays int `json:"retention_days"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.